import {BrowserRouter, Route, Routes, Navigate} from "react-router-dom";
import {HelmetProvider} from "react-helmet-async";
import StaffLayout from "./components/StaffLayout";
import UserLayout from "./components/UserLayout";
import BoatManager from "./pages/staff/BoatManager";
import BoatOverview from "./pages/staff/BoatOverview";
import BoatTypeOverview from "./pages/staff/BoatTypeOverview";
import BookingForm from "./pages/public/BookingForm";
import BookingSignOut from "./pages/public/BookingSignOut";
import BookingSignOutSuccess from "./pages/public/BookingSignOutSuccess";
import BookingSuccessful from "./pages/public/BookingSuccessful";
import Home from "./pages/public/Home";
import StaffLogin from "./pages/staff/StaffLogin"
import StatisticOverview from "./pages/staff/Statistics";
import Sports from "./pages/staff/Sports";
import Accounts from "./pages/staff/Accounts";

function Router() {
    return (
        <HelmetProvider>
            <BrowserRouter>
                <Routes>
                    <Route path="/" element={<UserLayout/>}>
                        {/* Home page (user) */}
                        <Route index element={<Home/>}/>
                        {/* Book a boat (user) */}
                        <Route path="book">
                            <Route index element={<BookingForm/>}/>
                            {/* After booking (user) */}
                            <Route path="success" element={<BookingSuccessful/>}/>
                        </Route>
                        <Route path="login">
                            <Route index element={<StaffLogin/>}/>
                        </Route>
                        {/* Sign out (user) */}
                        <Route path="signout">
                            <Route path=":id" element={<BookingSignOut/>}/>
                            {/* After Sign out (user) */}
                            <Route path="success" element={<BookingSignOutSuccess/>}/>
                        </Route>
                    </Route>
                    <Route path="staff" element={<StaffLayout/>}>
                        <Route path="" element={<Navigate to="/staff/overview"/>}/>
                        <Route path="overview" element={<BoatOverview/>}/>
                        <Route path="boattypes" element={<BoatTypeOverview/>}/>
                        <Route path="sports" element={<Sports/>}/>
                        <Route path="boats" element={<BoatManager/>}/>
                        <Route path="statistics" element={<StatisticOverview/>}/>
                        <Route path="accounts" element={<Accounts/>}/>
                    </Route>
                </Routes>
            </BrowserRouter>
        </HelmetProvider>
    );
}

export default Router;
