import { Container, Nav, Navbar } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import { Outlet, useLocation, NavLink, useNavigate } from "react-router-dom";
import { Helmet } from "react-helmet-async";
import { useEffect, useState } from "react";
import { getCurrentUser } from "../api/user";

function StaffLayout() {
  const { t } = useTranslation();
  const { pathname } = useLocation();
  const navigate = useNavigate();
  const [isCoord, setIsCoord] = useState<boolean>(false);

  async function validateCurrentUser() {
    try {
      const response = await getCurrentUser();
      if (response.status !== 200) {
        navigate("/login");
      } else {
        const json = await response.json();
        setIsCoord(json.result.role === "coordinator")
        if (json.result.role !== "coordinator" && pathname === "/staff/accounts") {
          navigate("/staff");
        }
      }
    } catch (e) { }
  }

  async function logout() {
    try {
      await fetch("/api/logout", {
        method: "POST",
      });
      navigate("/");
    } catch (e) {
      console.error(e);
    }
  }

  useEffect(() => {
    validateCurrentUser();
  }, []);

  return (
    <div className="h-100 w-100" style={{ "overflow": "none" }}>
      <Helmet>
        <title>{t(`routes.${pathname}`)}</title>
      </Helmet>
      <Navbar sticky="top" className="bg-secondary" variant="dark" expand="lg">
        <Container>
          <Navbar.Brand className="fw-bold" style={{ minWidth: "200px" }}>
            {t(`routes.${pathname}`)}
          </Navbar.Brand>
          <Navbar.Toggle />
          <Navbar.Collapse>
            <Nav className="mr-auto d-flex justify-content-between w-100">
              <div className="d-flex">
                <Nav activeKey={pathname}>
                  <Nav.Link as={NavLink} to="/staff/overview">
                    {t("staffNav.buttonBoatOverview")}
                  </Nav.Link>
                  <Nav.Link as={NavLink} to="/staff/boats">
                    {t("staffNav.buttonManageBoats")}
                  </Nav.Link>
                  <Nav.Link as={NavLink} to="/staff/boattypes">
                    {t("staffNav.buttonBoatTypes")}
                  </Nav.Link>
                  <Nav.Link as={NavLink} to="/staff/sports">
                    {t("staffNav.buttonSports")}
                  </Nav.Link>
                  <Nav.Link as={NavLink} to="/staff/statistics">
                    {t("staffNav.buttonStatistics")}
                  </Nav.Link>
                  {isCoord && <Nav.Link as={NavLink} to="/staff/accounts">
                    {t("staffNav.buttonAccounts")}
                  </Nav.Link>}
                </Nav>
              </div>
              <div>
                <Nav.Link
                  onClick={() => {
                    logout();
                  }}
                >
                  {t("staffNav.buttonLogout")}
                </Nav.Link>
              </div>
            </Nav>
          </Navbar.Collapse>
        </Container>
      </Navbar>
      <div style={{"overflow": "auto", "maxHeight": "calc(100vh - 56px)"}}>
        <Outlet />
      </div>
    </div>
  );
}

export default StaffLayout;
