import { useState, useEffect } from "react";
import { Button, Container, Row } from "react-bootstrap";
import { useTranslation } from "react-i18next";
import BoatTile from "../../components/BoatTile";
import StaffModal from "../../components/StaffModal";
import BoatInfo from "../../components/forms/BoatInfo";
import { useNavigate } from 'react-router-dom';
import { getBoatsOverview, lock, unlock } from "../../api/boat";
import { OverviewBoat } from "../../types";


function BoatOverview() {
	const { t } = useTranslation();
	const [infoElement, setInfoElement] = useState<any>(undefined);
	const [boats, setBoats] = useState<OverviewBoat[]>([]);
	const navigate = useNavigate();

	const getBoats = async () => {
		const boats = await getBoatsOverview();
		setBoats(boats.filter(x=>x.boattype !== undefined));
	};

	useEffect(() => {
		let stop: any = setInterval(() => { getBoats() }, 2000)
		return ()=>{
			stop();
		}
	}, []);

	return (
		<div className="text-center bg-light">
			<div className="boatViews text-center">
				<Row xs={1} xl={2}>
					<div>
						<div className="rentedOverdueView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.labelOverdue")}</h2>
							<div className="py-1">
								<Container >
									{(boats.filter(x => x.status === 3).length > 0) && <div className="mb-3">
										<div className="overdue-tiles text-center">
											<Row xs={1} md={2} >
												{/* TODO Time */}
												{boats.filter(x => x.status === 3).map(x =>
													<BoatTile isInUse={true} key={x.id} boatName={x.name} time={0} persons={x.boattype?.seats + " Person"} overdue={true} clickEvent={() => { setInfoElement(x) }}></BoatTile>
												)}
											</Row>
										</div>
									</div>}
									{(boats.filter(x => x.status === 3).length === 0) && <div style={{ height: "45px", verticalAlign: "middle" }}>{t("boatOverview.noBoatsAvailable")}</div>}
									{(boats.filter(x => x.status === 3).length > 4) && <Button variant="light" onClick={() => navigate('/staff/boats')} className="mb-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>}
								</Container>
							</div>
						</div>
					</div>

					<div>
						<div className="rentedView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.labelCurrentlyRented")}</h2>
							<div className="py-1">
								<Container>
									{(boats.filter(x => x.status === 2).length > 0) && <div className="mb-3">
										<div className="rented-tiles text-center">
											<Row xs={1} md={2}>
												{boats.filter(x => x.status === 2).map(x =>
													<BoatTile isInUse={true} key={x.id} boatName={x.name} time={0} persons={x.boattype?.seats + " Person"} overdue={false} clickEvent={() => { setInfoElement(x) }}></BoatTile>
												)}
											</Row>
										</div>
									</div>}
									{(boats.filter(x => x.status === 2).length === 0) && <div style={{ height: "45px", verticalAlign: "middle" }}>{t("boatOverview.noBoatsAvailable")}</div>}
									{(boats.filter(x => x.status === 2).length > 4) && <Button variant="light" onClick={() => navigate('/staff/boats')} className="mb-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>}
								</Container>
							</div>
						</div>
					</div>

					<div>
						<div className="blockedView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.blockedBoats")}</h2>
							<div className="py-1">
								<Container>
									{(boats.filter(x => x.status === 1).length > 0) && <div className="mb-3">
										<div className="blocked-tiles text-center">
											<Row xs={1} md={2}>
												{boats.filter(x => x.status === 1).map(x =>
													<BoatTile isInUse={false} key={x.id} boatName={x.name} time={0} persons={x.boattype?.seats + " Person"} changeLock={() => {
														unlock({ id: x.id }).then(async () => {
															await getBoats();
														});
													}} blocked={true} clickEvent={() => { setInfoElement(x) }}></BoatTile>
												)}
											</Row>
										</div>
									</div>}
									{(boats.filter(x => x.status === 1).length === 0) && <div style={{ height: "45px", verticalAlign: "middle" }}>{t("boatOverview.noBoatsAvailable")}</div>}
									{(boats.filter(x => x.status === 1).length > 4) && <Button variant="light" onClick={() => navigate('/staff/boats')} className="mb-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>}
								</Container>
							</div>
						</div>
					</div>

					<div>
						<div className="availableView bg-white border my-2">
							<h2 className="my-3">{t("boatOverview.availableBoats")}</h2>
							<div className="py-1">
								<Container>
									{(boats.filter(x => x.status === 0).length > 0) && <div className="mb-3">
										<div className="available-tiles text-center">
											<Row xs={1} md={2}>
												{boats.filter(x => x.status === 0).map(x =>
													<BoatTile isInUse={false} key={x.id} boatName={x.name} time={0} persons={x.boattype?.seats + " Person"} blocked={false} changeLock={() => {
														lock({ id: x.id }).then(async () => {
															await getBoats();
														});
													}} clickEvent={() => { setInfoElement(x) }}></BoatTile>
												)}
											</Row>
										</div>
									</div>}
									{(boats.filter(x => x.status === 0).length === 0) && <div style={{ height: "45px", verticalAlign: "middle" }}>{t("boatOverview.noBoatsAvailable")}</div>}
									{(boats.filter(x => x.status === 0).length > 4) && <Button variant="light" onClick={() => navigate('/staff/boats')} className="mb-3 shadow-sm bg-white border w-50 text-uppercase rounded-pill">{t("boatOverview.buttonShowAll")}</Button>}
								</Container>
							</div>
						</div>
					</div>

				</Row>
			</div>

			<StaffModal header={t("boatOverview.BoatInfo")} show={infoElement?.boatName} successText={t("boatOverview.EndRide")} successColor="dark" onHide={() => { setInfoElement(undefined) }} onSuccess={() => { setInfoElement(undefined) }}>
				<BoatInfo></BoatInfo>
			</StaffModal>

		</div>
	);
}

export default BoatOverview;
